==> SD35B_0.02.1_src.tar.gz: Sd35b/decoder/ScenarioDecoderSystem.h <==
/*
 * ScenarioDecoderSystem.h
 *		- "ALICE SOFT System3.x" compatible scenario decoder SD35
 *
 * Copyright (C) 1999 Atsushi Mizuguchi  All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA
 * 
 * 
 */

#ifndef __ScenarioDecoderSystem_h__
#define __ScenarioDecoderSystem_h__
/**********************************************************************
	Alice soft Scenario decoder system 3.x
**********************************************************************/
#include <string>
#include <vector>
typedef long HRESULT;

/////////////////////////////////////////////////////////////
// System3.5
// class
namespace ALSD {
//namespace ScenarioDecoder_System35 {
	class CFileCtrl;		// t@CRg[
	class CFileAld;			// ALDt@C
	class CFileData;		// ALDPt@C
	// [U[t@C
	class CAliceCG;			// PMS8/16, VSP...
	class COffScreen;		// rbg}bv(@ˑ)
	class CGraphicDriver;	// OtBbN
	class CGraphicView;		// r[(@ˑ)
	class CCDPlayer;		// CD-DA
	// MIDI
	// TEh
	class CExpressionDriver;// 
	class CCommandDriver;	// R}h
	class CScenarioDriver;	// X^bNAViIf[^
	class CScenarioParser;	// \́AǗ (: CScenarioDriver)
	class CScenarioDecoder;	// C[v

	class CSelectionCtrl;	// IR}hǗ
	class CMessageCtrl;		// bZ[W\Ǘ
};

// define system value
namespace ALSD {
//namespace ScenarioDecoder_System35 {
	const HRESULT ALSD_OK			=	   0;
	const HRESULT ALSD_WRN_GENERIC	=	   1;
	const HRESULT ALSD_ERR_GENERIC	=	  -1;

	const long ALSD_SDRV_STACKSIZE	= 1024;	// scenario driver stack size
	const long ALSD_ALDTYPE_MAX		= 5;	// Sx,Mx,Wx,Cx,Dx
	const long ALSD_ALDFILE_MAX		= 5;	// xA`xE

	const long ALSD_SEL_CHOICESMAX	= 20;

	const long ALSD_FILECTR_SAVEERR		= 255;
	const long ALSD_FILECTR_LOADERR		= 255;
	const long ALSD_FILECTR_LOADSHORTAGE= 254;
	const long ALSD_FILECTR_OTHERERR	= 201;
	const long ALSD_FILECTR_LOADOK		= 0;
	const long ALSD_FILECTR_SAVEOK1		= 1;
	const long ALSD_FILECTR_SAVEOK0		= 0;

};

// err exception
namespace ALSD {
//namespace ScenarioDecoder_System35 {
	class EALSD_Msg;
	class EALSD_FileNo;	// notify file number
	class EALSD_Exit;	// exit system
};

// file type
namespace ALSD {
//namespace ScenarioDecoder_System35 {
	enum FILEDATATYPE {
		DATATYPE_SCO	= 0,
		DATATYPE_CG		= 1,
		DATATYPE_WAV	= 2,
		DATATYPE_MIDI	= 3,
		DATATYPE_DATA	= 4,
	};
};

// function
#undef TRACE
namespace ALSD {
//namespace ScenarioDecoder_System35 {
	int TRACE( FILE *fp, const char *_Format ... );
	int TRACE( const char *_Format ... ); // output stderr
	int stricmp( const char *string1, const char *string2 );
};


/////////////////////////////////////////////////////////////
// System 3.6
//namespace ScenarioDecoder_System36 = ScenarioDecoder_System35;

/////////////////////////////////////////////////////////////
// short name (ALice soft Scenario Decoder system 3.x )
// namespace ALSD = ScenarioDecoder_System35;

#endif

==> SD35B_0.02.2_src.tar.gz: Sd35b/decoder/ScenarioDecoderSystem.h <==
/*
 * ScenarioDecoderSystem.h
 *		- "ALICE SOFT System3.x" compatible scenario decoder SD35
 *
 * Copyright (C) 1999 Atsushi Mizuguchi  All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA
 * 
 * 
 */

#ifndef __ScenarioDecoderSystem_h__
#define __ScenarioDecoderSystem_h__
/**********************************************************************
	Alice soft Scenario decoder system 3.x
**********************************************************************/
#include <string>
#include <vector>
typedef long HRESULT;

/////////////////////////////////////////////////////////////
// System3.5
// class
namespace ALSD {
//namespace ScenarioDecoder_System35 {
	class CFileCtrl;		// t@CRg[
	class CFileAld;			// ALDt@C
	class CFileData;		// ALDPt@C
	class CAliceCG;			// PMS8/16, VSP...
	class COffScreen;		// rbg}bv(@ˑ)
	class CGraphicView;		// r[(@ˑ^AvP[VIF)
	class CGraphicDriver;	// OtBbN
	class CUnitmapDriver;	// jbg}bv
	class CCDPlayer;		// CD-DA
	// MIDI
	// TEh
	class CExpressionDriver;// 
	class CCommandDriver;	// R}h
	class CScenarioDriver;	// X^bNAViIf[^
	class CScenarioParser;	// \́AǗ (: CScenarioDriver)
	class CScenarioDecoder;	// C[v

	class CSelectionCtrl;	// IR}hǗ
	class CMessageCtrl;		// bZ[W\Ǘ
};

// define system value
namespace ALSD {
//namespace ScenarioDecoder_System35 {
	const HRESULT ALSD_OK			=	   0;
	const HRESULT ALSD_WRN_GENERIC	=	   1;
	const HRESULT ALSD_ERR_GENERIC	=	  -1;

	const long ALSD_SDRV_STACKSIZE	= 1024;	// scenario driver stack size
	const long ALSD_ALDTYPE_MAX		= 5;	// Sx,Mx,Wx,Cx,Dx
	const long ALSD_ALDFILE_MAX		= 5;	// xA`xE

	const long ALSD_SEL_CHOICESMAX	= 20;

	const long ALSD_FILECTR_SAVEERR		= 255;
	const long ALSD_FILECTR_LOADERR		= 255;
	const long ALSD_FILECTR_LOADSHORTAGE= 254;
	const long ALSD_FILECTR_OTHERERR	= 201;
	const long ALSD_FILECTR_LOADOK		= 0;
	const long ALSD_FILECTR_SAVEOK1		= 1;
	const long ALSD_FILECTR_SAVEOK0		= 0;

};

// err exception
namespace ALSD {
//namespace ScenarioDecoder_System35 {
	class EALSD_Msg;
	class EALSD_FileNo;	// notify file number
	class EALSD_Exit;	// exit system
};

// file type
namespace ALSD {
//namespace ScenarioDecoder_System35 {
	enum FILEDATATYPE {
		DATATYPE_SCO	= 0,
		DATATYPE_CG		= 1,
		DATATYPE_WAV	= 2,
		DATATYPE_MIDI	= 3,
		DATATYPE_DATA	= 4,
	};
};

// function
#undef TRACE
namespace ALSD {
//namespace ScenarioDecoder_System35 {
	int TRACE( FILE *fp, const char *_Format ... );
	int TRACE( const char *_Format ... ); // output stderr
	int stricmp( const char *string1, const char *string2 );
};


/////////////////////////////////////////////////////////////
// System 3.6
//namespace ScenarioDecoder_System36 = ScenarioDecoder_System35;

/////////////////////////////////////////////////////////////
// short name (ALice soft Scenario Decoder system 3.x )
// namespace ALSD = ScenarioDecoder_System35;
// ǂnamespace ̕ʖʂȂRpC...
// VC/C++ClassViewȓɂȂ邵B


#endif
